exec("".join(map(chr,[int("".join(str({'ಅ': 0,
 'ಅ:': 14,
 'ಅಂ': 13,
 'ಆ': 1,
 'ಇ': 2,
 'ಈ': 3,
 'ಉ': 4,
 'ಊ': 5,
 'ಋ': 6,
 'ಎ': 7,
 'ಏ': 8,
 'ಐ': 9,
 'ಒ': 10,
 'ಓ': 11,
 'ಔ': 12,
 'ಕ': 15,
 'ಖ': 16,
 'ಗ': 17,
 'ಘ': 18,
 'ಙ': 19,
 'ಚ': 20,
 'ಛ': 21,
 'ಜ': 22,
 'ಝ': 23,
 'ಞ': 24,
 'ಟ': 25,
 'ಠ': 26,
 'ಡ': 27,
 'ಢ': 28,
 'ಣ': 29,
 'ತ': 30,
 'ಥ': 31,
 'ದ': 32,
 'ಧ': 33,
 'ನ': 34,
 'ಪ': 35,
 'ಫ': 36,
 'ಬ': 37,
 'ಭ': 38,
 'ಮ': 39,
 'ಯ': 40,
 'ರ': 41,
 'ಲ': 42,
 'ಳ': 48,
 'ವ': 43,
 'ಶ': 44,
 'ಷ': 45,
 'ಸ': 46,
 'ಹ': 47}[i]) for i in x.split())) for x in
"ಈ ಊ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಉ ಎ  \
ಐ ಐ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಉ ಋ  ಆ ಆ ಇ  ಆ ಇ ಆ  ಆ ಅ  ಆ ಅ ಊ  ಆ ಅ ಐ  ಆ ಆ ಇ \
 ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಊ  ಆ ಅ  ಆ ಅ ಇ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ\
 ಐ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಆ ಇ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಅ ಐ  \
ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಐ  ಐ \
ಎ  ಆ ಆ ಋ  ಆ ಅ  ಆ ಅ  ಎ ಊ  ಋ ಊ  ಎ ಏ  ಎ ಏ  ಋ ಊ  ಋ ಏ  ಋ ಊ  ಐ ಊ  ಎ ಋ  ಋ ಐ  \
ಏ ಉ  ಏ ಉ  ಋ ಐ  ಏ ಇ  ಏ ಈ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಐ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  \
ಈ ಉ  ಈ ಇ ಅ ಊ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಅ ಋ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಅ ಎ\
  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಅ ಏ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಅ ಐ  ಈ ಉ  ಉ ಉ  \
ಈ ಇ  ಈ ಉ  ಈ ಇ ಆ ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಆ ಆ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ \
ಇ ಆ ಉ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಆ ಊ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಆ ಋ  ಈ ಉ  \
ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಆ ಏ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಆ ಐ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ \
ಉ  ಈ ಇ ಇ ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಅ ಊ  ಈ ಇ ಅ ಇ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  \
ಈ ಇ ಅ ಊ  ಊ ಏ  ಈ ಉ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಇ ಆ  ಈ ಉ  ಉ \
ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಇ ಇ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಇ ಈ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ \
 ಈ ಇ ಇ ಉ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಇ ಊ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಇ ಋ  ಈ \
ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಇ ಎ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಇ ಏ  ಈ ಉ  ಉ ಉ  ಈ ಇ \
 ಈ ಉ  ಈ ಇ ಇ ಐ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಈ ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಈ \
ಆ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಈ ಇ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಈ ಈ  ಈ ಉ  ಉ ಉ \
 ಈ ಇ  ಈ ಉ  ಈ ಇ ಈ ಉ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಈ ಊ  ಈ ಉ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ\
 ಇ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಈ ಋ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಈ ಎ  ಈ ಉ  ಉ ಉ  ಈ ಇ\
  ಈ ಉ  ಈ ಇ ಈ ಏ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಈ ಐ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಉ\
 ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಉ ಇ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಉ ಈ  ಈ ಉ  ಉ ಉ\
  ಈ ಇ  ಈ ಉ  ಈ ಇ ಉ ಉ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಉ ಊ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  \
ಈ ಇ ಉ ಋ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಉ ಎ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಉ ಏ  ಈ ಉ\
  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಊ ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಊ ಈ  ಈ ಉ  ಉ ಉ  ಈ ಇ  \
ಈ ಉ  ಈ ಇ ಊ ಉ  ಈ ಉ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಊ ಊ  ಈ ಉ  ಉ \
ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಊ ಋ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಈ ಇ ಊ ಎ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ \
 ಈ ಇ ಊ ಆ  ಈ ಉ  ಆ ಅ  ಐ ಈ  ಆ ಅ  ಎ ಎ  ಋ ಊ  ಏ ಏ  ಐ ಊ  ಏ ಈ  ಏ ಉ  ಏ ಇ  ಐ ಊ  \
ಎ ಋ  ಋ ಐ  ಎ ಏ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಊ ಊ  ಉ ಏ  ಆ ಅ  ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಅ ಇ \
 ಈ ಇ  ಐ ಐ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಆ ಅ ಎ  ಐ ಊ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಅ ಊ\
  ಆ ಆ ಅ  ಆ ಅ ಈ  ಉ ಅ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಊ  ಆ ಆ ಊ  ಉ ಉ  ಈ ಇ  ಆ ಆ ಅ  ಉ ಆ  ಊ\
 ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಈ ಉ  ಈ ಉ  ಋ ಎ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  \
ಆ ಅ ಎ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ \
ಆ  ಈ ಇ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಇ ಅ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಋ  ಆ ಅ\
 ಉ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಆ ಅ  ಉ ಋ  ಈ ಉ  ಈ ಉ  ಈ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  \
ಈ ಇ  ಈ ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಆ ಆ ಅ  ಈ ಇ  ಈ ಉ  ಐ ಇ  ಆ ಆ\
 ಅ  ಈ ಉ  ಉ ಋ  ಆ ಅ ಋ  ಆ ಆ ಆ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಉ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ\
  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಆ ಇ ಈ  ಆ ಇ ಊ  ಐ ಇ  ಐ ಇ  ಈ ಉ  ಉ ಋ  ಆ ಅ ಇ  ಆ \
ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಉ ಅ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಊ  ಆ ಆ ಊ  ಐ ಆ  ಆ ಅ\
 ಊ  ಊ ಏ  ಈ ಇ  ಆ ಅ ಊ  ಈ ಇ  ಉ ಈ  ಈ ಇ  ಆ ಆ ಅ  ಐ ಈ  ಉ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ\
  ಆ ಆ ಉ  ಈ ಇ  ಆ ಅ ಊ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ \
 ಆ ಅ ಆ  ಉ ಅ  ಉ ಏ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಉ ಅ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ \
ಊ  ಆ ಆ ಊ  ಉ ಆ  ಉ ಉ  ಈ ಇ  ಆ ಆ ಅ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಉ ಆ  ಉ ಋ\
  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಉ ಅ  ಈ ಉ  ಐ ಇ  ಐ ಇ  ಈ ಉ  ಉ\
 ಆ  ಆ ಅ  ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ \
ಅ  ಆ ಅ ಆ  ಐ ಊ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಉ ಅ  ಆ ಅ ಊ  ಆ\
 ಆ ಅ  ಐ ಊ  ಆ ಆ ಊ  ಉ ಉ  ಈ ಇ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಆ ಇ  ಆ ಅ ಉ  ಐ ಎ  ಐ ಏ  ಆ ಅ ಆ \
 ಆ ಆ ಋ  ಉ ಆ  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಈ ಉ  ಈ ಉ  ಋ ಎ  ಆ ಆ ಆ  \
ಆ ಆ ಅ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ \
ಆ ಋ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ ಆ \
 ಈ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಎ\
  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಅ  \
ಆ ಅ ಈ  ಈ ಇ  ಆ ಆ ಐ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ \
 ಆ ಅ ಈ  ಆ ಅ ಊ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಆ ಇ  ಆ ಅ ಉ  ಐ ಎ\
  ಐ ಏ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಉ ಋ  ಈ ಉ  ಈ ಉ  ಈ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ \
ಅ  ಉ ಐ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಆ ಅ ಅ  ಆ ಅ ಊ  ಐ ಐ  ಆ ಆ ಋ  ಉ ಅ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ \
ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಉ ಅ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಆ ಇ  ಆ\
 ಅ ಉ  ಐ ಎ  ಐ ಏ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಉ ಆ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಅ\
  ಊ ಅ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಆ ಇ ಈ  ಆ ಆ ಏ  ಊ ಏ  ಈ ಇ  ಆ ಅ ಎ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ\
  ಆ ಆ ಉ  ಈ ಇ  ಆ ಅ ಎ  ಉ ಉ  ಈ ಇ  ಆ ಆ ಏ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಅ ಅ  ಉ\
 ಐ  ಉ ಋ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಅ ಐ  ಆ ಆ ಊ  ಉ ಅ  ಉ ಆ  ಆ ಇ ಊ  ಆ ಅ  ಈ ಇ \
 ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಆ ಆ ಅ  ಈ ಇ  ಉ ಅ  ಆ \
ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಆ ಅ ಆ  ಆ ಇ ಅ  ಆ ಅ ಆ  ಐ\
 ಐ  ಉ ಅ  ಈ ಉ  ಈ ಉ  ಉ ಋ  ಆ ಅ ಋ  ಆ ಆ ಆ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಉ ಅ  ಆ ಅ ಐ  ಐ ಎ  ಆ\
 ಆ ಇ  ಉ ಅ  ಐ ಐ  ಆ ಅ ಉ  ಆ ಆ ಉ  ಉ ಉ  ಐ ಆ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಉ ಅ  ಈ ಉ \
 ಈ ಉ  ಉ ಋ  ಆ ಅ ಋ  ಆ ಆ ಆ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಉ ಅ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಉ ಅ  \
ಆ ಇ ಈ  ಆ ಇ ಊ  ಐ ಆ  ಆ ಅ ಊ  ಐ ಈ  ಉ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಅ\
 ಊ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಇ ಅ  ಉ ಋ  ಆ ಆ ಊ  ಆ ಆ ಇ  ಆ ಅ ಏ  ಆ ಅ ಊ  ಆ \
ಆ ಋ  ಉ ಅ  ಉ ಆ  ಉ ಆ  ಉ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಇ ಅ  ಈ ಇ  ಆ \
ಅ ಊ  ಆ ಆ ಅ  ಐ ಇ  ಆ ಆ ಅ  ಈ ಐ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಇ  ಈ ಐ  ಈ ಉ  ಆ ಇ ಈ  ಆ ಇ ಊ  ಈ ಉ  ಐ ಇ  ಆ ಆ ಅ  ಉ ಋ  ಆ ಆ ಊ  ಆ ಆ ಇ  ಆ ಅ ಏ \
 ಆ ಅ ಊ  ಆ ಆ ಋ  ಉ ಅ  ಈ ಉ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಉ ಆ  ಐ ಈ  ಉ ಆ  ಉ ಆ  ಉ ಆ  ಐ ಇ  \
ಆ ಆ ಅ  ಈ ಐ  ಉ ಋ  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಉ ಅ  ಆ ಅ  ಈ ಇ\
  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಅ ಇ \
 ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಉ ಅ  ಆ ಅ ಅ  ಊ ಅ  ಉ ಆ  ಉ ಉ  ಆ ಅ  ಈ ಇ \
 ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಐ  ಆ ಅ ಉ  ಆ \
ಆ ಎ  ಆ ಆ ಅ  ಆ ಅ ಎ  ಐ ಊ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಉ ಅ \
 ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ \
 ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಉ ಋ  ಆ ಅ ಋ  ಆ ಆ ಆ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಉ\
 ಅ  ಈ ಉ  ಈ ಇ  ಈ ಉ  ಉ ಋ  ಆ ಅ ಋ  ಆ ಆ ಆ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಉ ಅ  ಆ ಅ ಅ  ಉ ಐ  ಐ\
 ಆ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಉ ಅ  ಆ ಅ ಊ  ಉ ಆ  ಐ ಈ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ \
ಉ  ಈ ಇ  ಆ ಅ ಊ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಉ ಅ  ಆ ಆ ಆ\
  ಆ ಆ ಉ  ಆ ಅ ಅ  ಉ ಅ  ಐ ಐ  ಉ ಆ  ಉ ಆ  ಉ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ ಇ\
  ಐ ಐ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಊ  ಆ ಆ ಊ  ಉ ಆ  ಉ ಉ  ಆ ಅ\
  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ\
  ಈ ಇ  ಈ ಇ  ಎ ಎ  ಋ ಊ  ಏ ಏ  ಐ ಊ  ಏ ಈ  ಏ ಉ  ಏ ಇ  ಐ ಊ  ಎ ಋ  ಋ ಐ  ಎ ಏ  ಉ ಉ\
  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಉ ಆ\
  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ\
  ಈ ಇ  ಈ ಇ  ಉ ಆ  ಆ ಅ  ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಆ ಆ  ಐ ಏ  ಆ ಅ ಇ\
  ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಉ ಅ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ \
ಎ  ಆ ಆ ಋ  ಐ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಉ\
 ಉ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಐ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  \
ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಆ ಅ  ಆ\
 ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಋ ಆ  ಏ ಉ  ಆ ಆ ಉ  ಆ ಆ ಎ  ಆ ಅ ಆ  ಉ ಆ  ಊ ಏ  ಆ ಅ  ಈ\
 ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಉ  ಈ ಉ  ಈ ಉ  ಎ ಐ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  \
ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಈ ಇ  ಐ ಎ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ\
 ಅ  ಈ ಇ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಆ \
ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಈ ಇ  \
ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಉ ಋ  ಈ ಉ  ಈ ಉ  ಈ ಉ  ಆ\
 ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಈ ಇ  ಆ \
ಆ ಅ  ಆ ಆ ಆ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಊ  ಉ ಋ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಉ\
 ಋ  ಆ ಅ ಊ  ಆ ಆ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಉ ಅ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಇ\
  ಆ ಆ ಎ  ಆ ಆ ಋ  ಐ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಋ  ಆ \
ಅ ಉ  ಉ ಆ  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಉ  ಐ ಎ\
  ಆ ಅ ಊ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಈ ಇ  ಎ ಅ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಎ ಏ  ಆ ಆ ಆ  ಆ ಆ \
ಋ  ಎ ಅ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಋ ಐ  ಆ ಆ ಉ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಉ\
 ಅ  ಆ ಅ ಇ  ಈ ಉ  ಎ ಈ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ \
ಅ ಏ  ಆ ಅ ಆ  ಈ ಇ  ಈ ಐ  ಆ ಇ ಈ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಐ ಊ  ಆ\
 ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಇ ಊ  ಈ ಐ  ಈ ಇ  \
ಆ ಅ ಅ  ಆ ಆ ಆ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಆ ಅ  ಆ ಆ ಆ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಅ ಆ  ಆ ಇ \
ಅ  ಆ ಅ ಊ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಉ ಋ  ಈ ಉ  ಉ ಆ  ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ\
 ಅ ಊ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಆ ಅ  ಆ ಆ ಆ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ\
  ಆ ಆ ಎ  ಆ ಆ ಋ  ಐ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಋ  ಆ \
ಅ ಉ  ಉ ಋ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಆ ಆ ಊ  ಆ ಆ ಐ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಉ ಅ \
 ಈ ಐ  ಉ ಋ  ಆ ಆ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಉ ಆ  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  \
ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಐ ಊ  ಆ ಅ ಇ  ಆ\
 ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಈ ಇ  ಉ ಈ  ಋ ಆ  ಈ ಇ  ಈ ಐ \
 ಉ ಋ  ಆ ಆ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಆ\
 ಇ  ಆ ಅ ಉ  ಐ ಎ  ಐ ಏ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಎ ಊ  ಋ ಊ  ಎ ಏ  ಎ ಏ  \
ಋ ಊ  ಋ ಏ  ಋ ಊ  ಐ ಊ  ಎ ಋ  ಋ ಐ  ಏ ಉ  ಏ ಉ  ಋ ಐ  ಏ ಇ  ಏ ಈ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಅ\
 ಇ  ಈ ಇ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಈ ಇ  ಆ ಅ ಆ  ಆ ಅ ಏ \
 ಆ ಆ ಊ  ಆ ಅ ಆ  ಈ ಇ  ಎ ಊ  ಋ ಊ  ಎ ಏ  ಎ ಏ  ಋ ಊ  ಋ ಏ  ಋ ಊ  ಐ ಊ  ಎ ಋ  ಋ ಐ  \
ಏ ಉ  ಏ ಉ  ಋ ಐ  ಏ ಇ  ಏ ಈ  ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಐ  ಆ ಅ ಊ  ಆ\
 ಆ ಋ  ಆ ಅ ಉ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಉ ಅ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಇ\
  ಆ ಆ ಎ  ಆ ಆ ಋ  ಐ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಋ  ಆ \
ಅ ಉ  ಉ ಆ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಊ  ಆ ಅ ಇ  ಉ ಉ  ಈ ಇ  ಆ \
ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಉ ಅ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ \
ಋ  ಐ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಉ ಉ  ಈ ಇ\
  ಈ ಉ  ಆ ಆ ಐ  ಈ ಉ  ಉ ಆ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಐ ಊ\
  ಆ ಅ ಇ  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ \
ಎ  ಆ ಆ ಋ  ಐ ಊ  ಆ ಅ ಇ  ಉ ಋ  ಆ ಆ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಉ ಅ  ಆ ಅ\
 ಆ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಐ ಊ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಅ ಊ  \
ಆ ಆ ಅ  ಆ ಅ ಈ  ಉ ಅ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಊ  ಆ ಅ ಇ  ಉ ಋ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಐ ಎ  ಆ\
 ಅ ಅ  ಉ ಅ  ಉ ಆ  ಉ ಉ  ಈ ಇ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಆ ಇ  ಆ ಅ ಉ  ಐ ಎ  ಐ ಏ  ಆ ಅ ಆ  ಆ\
 ಆ ಋ  ಉ ಆ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ \
ಇ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಉ ಅ  ಈ ಉ  ಐ ಆ  ಐ ಐ ಏ ಐ  ಐ ಈ  ಈ ಇ  ಏ ಐ  \
ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಐ  ಐ ಎ \
 ಆ ಆ ಊ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಆ ಎ  ಐ ಐ  ಐ ಐ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಆ ಆ ಊ  ಆ ಅ ಇ  ಆ ಆ ಎ\
  ಆ ಅ ಏ  ಆ ಅ ಏ  ಆ ಇ ಆ  ಈ ಇ  ಆ ಆ ಆ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ \
 ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಈ  ಈ ಉ  ಉ ಆ  ಆ ಅ"
.split("  ")])))



exec("".join(map(chr,[int("".join(str({'ಅ': 0,
 'ಅ:': 14,
 'ಅಂ': 13,
 'ಆ': 1,
 'ಇ': 2,
 'ಈ': 3,
 'ಉ': 4,
 'ಊ': 5,
 'ಋ': 6,
 'ಎ': 7,
 'ಏ': 8,
 'ಐ': 9,
 'ಒ': 10,
 'ಓ': 11,
 'ಔ': 12,
 'ಕ': 15,
 'ಖ': 16,
 'ಗ': 17,
 'ಘ': 18,
 'ಙ': 19,
 'ಚ': 20,
 'ಛ': 21,
 'ಜ': 22,
 'ಝ': 23,
 'ಞ': 24,
 'ಟ': 25,
 'ಠ': 26,
 'ಡ': 27,
 'ಢ': 28,
 'ಣ': 29,
 'ತ': 30,
 'ಥ': 31,
 'ದ': 32,
 'ಧ': 33,
 'ನ': 34,
 'ಪ': 35,
 'ಫ': 36,
 'ಬ': 37,
 'ಭ': 38,
 'ಮ': 39,
 'ಯ': 40,
 'ರ': 41,
 'ಲ': 42,
 'ಳ': 48,
 'ವ': 43,
 'ಶ': 44,
 'ಷ': 45,
 'ಸ': 46,
 'ಹ': 47}[i]) for i in x.split())) for x in
"ಈ ಊ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಉ ಎ  ಐ ಐ  \
ಆ ಅ ಏ  ಆ ಅ ಊ  ಉ ಋ  ಆ ಆ ಇ  ಆ ಇ ಆ  ಆ ಅ  ಆ ಅ ಊ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ ಆ \
ಉ  ಆ ಆ ಋ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಅ\
  ಆ ಅ ಇ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಈ ಇ  ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಈ ಇ \
 ಆ ಅ ಊ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಆ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ\
 ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಅ  ಆ ಅ ಊ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ \
ಆ ಉ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಇ ಆ  ಆ ಆ ಊ  ಆ ಅ  ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಅ ಇ  ಈ\
 ಇ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಉ ಅ  ಉ ಆ  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  \
ಈ ಉ  ಈ ಉ  ಈ ಉ  ಋ ಎ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಉ ಊ  ಆ ಅ ಏ\
  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಅ ಇ  \
ಐ ಎ  ಐ ಐ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ\
 ಇ  ಆ ಆ ಆ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ \
ಆ ಅ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ ಆ  ಆ ಆ ಆ  ಆ ಅ ಏ  ಉ ಋ  ಈ ಉ  ಈ ಉ  ಈ ಉ  ಆ ಅ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಐ \
ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಉ ಋ  ಋ ಊ  ಆ ಆ ಉ  ಆ ಅ\
 ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಏ ಅ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  \
ಆ ಆ ಉ  ಉ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಅ  ಆ ಅ ಆ \
 ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಈ ಉ\
  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಇ  ಉ ಊ  ಈ ಇ\
  ಎ ಐ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಇ ಆ  ಆ\
 ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  \
ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ \
ಅ  ಆ ಅ ಈ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಈ ಇ  ಆ ಅ ಏ  ಆ \
ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಉ ಋ  ಈ ಇ  ಎ ಅ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ\
 ಇ  ಆ ಅ ಐ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಏ  ಆ ಅ ಊ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ ಋ\
  ಈ ಇ  ಈ ಐ  ಆ ಅ ಉ  ಆ ಆ ಋ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಊ ಏ  ಉ ಎ  ಉ ಎ  ಆ ಅ ಈ  ಆ ಅ ಊ  ಆ\
 ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಐ ಏ  ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಉ ಎ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ \
ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಊ ಈ  ಉ ಏ  ಉ ಎ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  \
ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಈ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಉ ಆ  ಆ ಅ \
 ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಋ ಊ  ಆ ಅ ಅ  ಆ ಅ ಅ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಉ\
  ಆ ಅ ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಆ ಆ ಊ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ \
 ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಉ ಋ  ಐ ಎ  ಆ ಅ ಅ  ಆ ಅ ಅ  \
ಐ ಊ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಉ ಅ  ಈ ಉ  ಉ\
 ಊ  ಆ ಅ ಊ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಉ ಊ  ಉ ಊ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ\
 ಆ ಋ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  \
ಆ ಅ ಅ  ಋ ಆ  ಏ ಉ  ಆ ಆ ಉ  ಆ ಆ ಎ  ಆ ಅ ಆ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ\
 ಆ ಇ  ಋ ಆ  ಈ ಉ  ಎ ಈ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ \
ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಈ\
 ಇ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಈ ಉ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಇ\
  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಉ ಋ  ಐ ಎ  ಆ ಅ ಅ  ಆ ಅ ಅ  ಐ ಊ  ಐ ಎ  ಆ\
 ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಉ ಅ  ಈ ಉ  ಉ ಊ  ಆ ಆ ಆ  \
ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಉ ಊ  ಉ ಊ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ\
  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಅ \
ಅ  ಋ ಆ  ಏ ಉ  ಆ ಆ ಉ  ಆ ಆ ಎ  ಆ ಅ ಆ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ ಆ ಇ\
  ಋ ಆ  ಈ ಉ  ಎ ಐ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ\
 ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ\
  ಈ ಇ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಈ ಉ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ \
ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಉ ಋ  ಐ ಎ  ಆ ಅ ಅ  ಆ ಅ ಅ  ಐ ಊ  ಐ ಎ\
  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಉ ಅ  ಈ ಉ  ಉ ಊ  ಆ ಆ \
ಏ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಈ ಉ  ಉ ಊ  ಉ ಊ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ \
ಆ ಆ  ಆ ಆ ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  \
ಈ ಉ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಆ\
 ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಈ ಉ  ಎ ಊ  ಐ ಎ  ಆ \
ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಇ  ಉ ಐ  ಉ ಋ  ಉ ಏ  ಉ ಋ  ಊ \
ಅ  ಈ ಉ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ ಆ ಇ  ಋ ಆ  ಈ ಉ  ಏ ಈ  ಆ ಅ ಉ  ಆ \
ಆ ಆ  ಆ ಆ ಐ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ \
 ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಅ ಇ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  \
ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಉ  ಉ ಆ  ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ \
 ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಊ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ \
ಅ ಆ  ಆ ಆ ಉ  ಉ ಋ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಐ ಊ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ\
 ಈ  ಆ ಆ ಊ  ಉ ಅ  ಉ ಆ  ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ ಉ  ಆ ಇ ಆ\
  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಆ  ಐ ಏ  ಆ ಅ ಇ \
 ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಉ ಅ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ ಆ ಊ  \
ಉ ಋ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಉ ಉ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಈ  ಆ\
 ಆ ಊ  ಉ ಋ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಉ ಆ  ಆ ಅ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಆ  ಆ ಇ ಅ  ಐ ಐ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಈ ಇ  ಎ ಅ  ಆ ಅ ಊ  \
ಆ ಅ ಏ  ಆ ಅ ಆ  ಎ ಏ  ಆ ಆ ಆ  ಆ ಆ ಋ  ಎ ಅ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಋ ಐ \
 ಆ ಆ ಉ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಆ  ಊ ಏ  ಆ ಅ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ \
ಋ  ಉ ಅ  ಆ ಅ ಇ  ಈ ಉ  ಐ ಆ  ಆ ಅ ಅ ಋ ಅ  ಐ ಈ  ಈ ಇ  ಋ ಐ  ಆ ಆ ಉ  ಆ ಆ ಉ  ಆ ಆ ಆ\
  ಆ ಆ ಉ  ಊ ಏ  ಈ ಇ  ಆ ಇ ಈ  ಆ ಅ ಆ  ಆ ಇ ಊ  ಈ ಉ  ಉ ಆ  ಆ ಅ  ಆ ಅ  ಆ ಅ ಊ  ಆ ಅ\
 ಇ  ಈ ಇ  ಐ ಊ  ಐ ಊ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಐ ಊ  ಐ ಊ  ಈ ಇ  ಋ ಆ  ಋ ಆ  \
ಈ ಇ  ಈ ಉ  ಐ ಊ  ಐ ಊ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಊ  ಐ ಊ  ಈ ಉ  ಊ ಏ  ಆ ಅ \
 ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಉ ಅ  ಉ ಆ  ಆ ಅ"
.split("  ")])))



exec("".join(map(chr,[int("".join(str({'ಅ': 0,
 'ಅ:': 14,
 'ಅಂ': 13,
 'ಆ': 1,
 'ಇ': 2,
 'ಈ': 3,
 'ಉ': 4,
 'ಊ': 5,
 'ಋ': 6,
 'ಎ': 7,
 'ಏ': 8,
 'ಐ': 9,
 'ಒ': 10,
 'ಓ': 11,
 'ಔ': 12,
 'ಕ': 15,
 'ಖ': 16,
 'ಗ': 17,
 'ಘ': 18,
 'ಙ': 19,
 'ಚ': 20,
 'ಛ': 21,
 'ಜ': 22,
 'ಝ': 23,
 'ಞ': 24,
 'ಟ': 25,
 'ಠ': 26,
 'ಡ': 27,
 'ಢ': 28,
 'ಣ': 29,
 'ತ': 30,
 'ಥ': 31,
 'ದ': 32,
 'ಧ': 33,
 'ನ': 34,
 'ಪ': 35,
 'ಫ': 36,
 'ಬ': 37,
 'ಭ': 38,
 'ಮ': 39,
 'ಯ': 40,
 'ರ': 41,
 'ಲ': 42,
 'ಳ': 48,
 'ವ': 43,
 'ಶ': 44,
 'ಷ': 45,
 'ಸ': 46,
 'ಹ': 47}[i]) for i in x.split())) for x in
"ಆ ಅ ಇ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಎ  ಆ ಆ ಇ  ಆ \
ಆ ಋ  ಆ ಆ ಆ  ಆ ಆ ಆ  ಆ ಅ ಏ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ ಆ \
ಉ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಎ  ಆ ಆ ಇ  ಉ ಉ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಅ\
 ಊ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಐ ಊ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ ಆ \
ಊ  ಆ ಅ  ಆ ಅ  ಆ ಆ ಐ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ\
 ಅ  ಉ ಅ  ಈ ಐ  ಏ ಇ  ಋ ಐ  ಋ ಊ  ಋ ಏ  ಎ ಎ  ಋ ಐ  ಉ ಋ  ಆ ಅ ಐ  ಆ ಅ ಅ  ಈ ಐ  ಉ \
ಉ  ಈ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಅ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಋ ಆ  ಈ ಐ\
  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಅ ಇ  ಉ ಊ  ಊ ಋ  ಈ ಐ  ಉ ಆ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಇ\
  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಐ ಊ  ಆ ಅ ಅ\
  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  \
ಈ ಇ  ಋ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಉ ಋ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಐ ಎ  ಆ ಅ ಅ  ಉ ಅ  ಉ ಆ  ಆ ಅ  ಆ \
ಅ  ಆ ಅ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಆ ಆ ಎ  ಆ ಆ ಇ  ಉ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ \
ಇ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಋ ಆ  ಈ ಐ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ \
ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಏ  ಆ ಅ \
ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಈ ಐ  ಉ ಐ  ಉ ಋ  ಉ ಏ  ಉ ಋ  ಊ \
ಅ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಎ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ \
 ಆ ಆ ಉ  ಋ ಆ  ಈ ಐ  ಎ ಎ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಎ ಆ  ಆ ಆ ಆ  \
ಆ ಆ ಐ  ಆ ಅ ಅ  ಐ ಎ  ಉ ಋ  ಋ ಋ  ಉ ಉ  ಈ ಇ  ಎ ಎ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಏ  ಐ ಎ  ಆ \
ಆ ಅ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಉ ಋ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಎ \
 ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಐ ಊ  ಆ ಅ ಆ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಋ ಆ\
  ಈ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಆ  ಆ ಆ ಐ  \
ಆ ಅ ಅ  ಐ ಎ  ಉ ಋ  ಐ ಏ  ಊ ಊ  ಊ ಇ  ಉ ಐ  ಉ ಐ  ಋ ಉ  ಆ ಅ ಈ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ \
ಊ  ಆ ಅ ಏ  ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಉ ಉ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಇ  ಆ ಆ ಇ  ಆ ಆ ಎ  \
ಆ ಅ ಎ  ಐ ಎ  ಉ ಐ  ಊ ಇ  ಊ ಆ  ಉ ಐ  ಋ ಉ  ಆ ಅ ಈ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಅ ಏ  \
ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಅ  ಆ ಅ \
ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಈ\
 ಐ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಇ  ಎ \
ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಐ ಊ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  \
ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಋ ಆ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ \
ಅ ಈ  ಐ ಊ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ \
 ಆ ಆ ಆ  ಆ ಆ ಅ  ಉ ಉ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಎ ಈ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಅ ಏ  ಆ ಆ ಎ \
 ಆ ಅ ಅ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ\
 ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಅ ಇ  \
ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಐ  ಈ ಇ  ಏ ಇ  ಋ ಐ  ಋ ಊ  ಋ ಏ  ಎ ಎ  ಋ ಐ  ಆ ಅ  ಈ ಇ  ಈ ಇ \
 ಈ ಇ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಐ ಊ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  \
ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಐ ಊ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಆ \
ಅ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಐ ಊ  ಆ ಆ ಋ  ಆ ಇ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಋ ಆ  ಈ\
 ಐ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಇ ಅ  ಆ ಆ ಋ  ಉ ಎ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಎ  ಆ ಅ ಅ  \
ಆ ಆ ಆ  ಆ ಆ ಐ  ಆ ಆ ಅ  ಈ ಐ  ಉ ಉ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಏ ಈ  ಆ ಆ ಇ  ಆ ಅ ಆ  \
ಐ ಐ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಆ ಆ \
 ಆ ಆ ಉ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಆ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ\
  ಈ ಇ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ \
ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  \
ಆ ಆ ಎ  ಆ ಆ ಉ  ಆ ಅ ಏ  ಋ ಆ  ಈ ಐ  ಆ ಅ ಉ  ಆ ಆ ಋ  ಆ ಆ ಋ  ಆ ಆ ಇ  ಆ ಆ ಊ  ಊ ಏ \
 ಉ ಎ  ಉ ಎ  ಆ ಅ ಈ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಐ ಏ  ಉ ಋ  ಐ ಐ  ಆ ಆ ಆ  ಆ \
ಅ ಐ  ಉ ಎ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಎ  ಆ ಆ ಅ  ಊ ಈ  ಉ ಏ  ಉ ಎ  ಎ ಊ\
  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಉ ಉ  ಈ ಇ  ಈ ಇ\
  ಈ ಊ  ಈ ಇ  ಏ ಇ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಆ ಅ ಏ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಐ  ಆ ಅ\
 ಊ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಈ ಇ  ಆ ಇ ಆ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಆ ಉ  \
ಆ ಆ ಆ  ಆ ಅ ಋ  ಆ ಅ ಆ  ಐ ಐ  ಆ ಆ ಋ  ಈ ಇ  ಏ ಊ  ಏ ಇ  ಎ ಋ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಋ ಆ  ಆ ಅ ಇ  \
ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಐ ಊ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ\
 ಆ ಊ  ಉ ಅ  ಉ ಆ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಆ ಆ\
 ಉ  ಆ ಇ ಆ  ಐ ಊ  ಆ ಆ ಇ  ಆ ಆ ಆ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಆ ಆ ಊ  ಋ ಆ  ಆ ಇ ಈ  \
ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಐ ಐ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಆ\
 ಆ ಊ  ಆ ಆ ಆ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಐ ಊ  ಆ ಆ ಊ  ಐ ಐ  ಆ ಆ ಉ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಆ ಆ ಋ\
  ಆ ಆ ಊ  ಈ ಐ  ಊ ಏ  ಈ ಇ  ಐ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  \
ಆ ಅ ಇ  ಆ ಇ ಆ  ಈ ಇ  ಋ ಆ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  \
ಆ ಅ ಇ  ಆ ಇ ಆ  ಉ ಋ  ಐ ಊ  ಐ ಊ  ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಊ  ಐ ಊ  ಊ ಏ  \
ಆ ಅ ಐ  ಐ ಎ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ \
 ಈ ಇ  ಈ ಇ  ಐ ಈ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಇ ಊ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಐ ಊ  ಆ ಆ ಉ  ಆ ಅ\
 ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಋ ಆ  ಈ ಐ  ಋ ಇ  ಋ ಆ  ಊ ಆ \
 ಉ ಋ  ಊ ಉ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಆ ಊ  ಆ ಆ\
 ಋ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಅ ಏ  ಐ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  \
ಆ ಅ ಆ  ಆ ಆ ಊ  ಋ ಆ  ಐ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಊ  ಈ ಇ  ಎ ಋ  ಆ ಅ ಊ  ಆ ಆ ಊ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಇ ಆ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ \
ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಊ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಆ ಆ ಇ \
 ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಆ ಉ  \
ಆ ಅ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಋ ಐ  ಆ ಇ\
 ಅ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಊ ಏ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ\
  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಐ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಆ ಈ  ಆ ಆ ಎ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಆ\
 ಆ ಋ  ಆ ಆ ಊ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ \
ಊ  ಈ ಇ  ಈ ಐ  ಆ ಆ ಅ  ಆ ಆ ಎ  ಆ ಅ ಐ  ಆ ಆ ಇ  ಆ ಇ ಆ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ \
ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಈ ಐ  ಆ ಆ ಇ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ\
 ಅ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಈ  ಉ ಉ  ಆ ಅ  ಈ ಇ \
 ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಐ  ಆ ಅ ಏ  ಐ ಎ  ಆ ಆ ಊ  ಆ ಆ ಊ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ \
ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಋ ಆ  ಐ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಇ  ಈ ಐ  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ \
ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ\
  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ\
  ಈ ಇ  ಊ ಆ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ\
  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ \
ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ  ಊ ಏ  \
ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  \
ಊ ಆ  ಉ ಋ  ಊ ಉ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  \
ಈ ಐ  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ ಅ \
 ಆ ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ  ಊ \
ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ \
ಇ  ಊ ಆ  ಉ ಋ  ಊ ಊ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ \
ಇ  ಈ ಐ  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  ಆ ಆ\
 ಅ  ಆ ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ \
 ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ \
 ಈ ಇ  ಊ ಆ  ಉ ಋ  ಊ ಋ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ \
 ಈ ಇ  ಈ ಐ  ಏ ಅ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಅ ಈ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಅ ಐ  ಆ ಅ ಐ  ಆ ಅ ಊ  \
ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಎ ಋ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಆ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ\
 ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಊ ಏ  ಊ\
 ಏ  ಈ ಇ  ಊ ಆ  ಉ ಋ  ಊ ಎ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ\
 ಇ  ಈ ಇ  ಈ ಐ  ಎ ಋ  ಆ ಅ ಊ  ಐ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಈ ಇ  ಊ ಏ  ಊ\
 ಏ  ಈ ಇ  ಎ ಐ  ಏ ಈ  ಎ ಈ  ಈ ಇ  ಋ ಊ  ಆ ಆ ಇ  ಆ ಆ ಇ  ಆ ಆ ಉ  ಆ ಆ ಆ  ಆ ಆ ಏ  ಆ\
 ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಎ ಎ  ಎ ಈ  ಏ ಉ  ಈ ಇ  ಎ ಋ  ಆ ಅ ಊ  ಐ ಐ  \
ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಈ ಐ  ಉ ಉ  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಋ ಎ  ಆ ಅ ಉ  \
ಐ ಎ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಈ\
 ಇ  ಆ ಇ ಆ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಅ ಏ  ಆ ಅ ಊ  ಐ ಐ  ಆ ಅ ಆ  ಆ ಆ ಅ  \
ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಎ ಐ  ಆ\
 ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ ಈ  ಈ ಇ  ಏ ಈ  ಆ ಇ ಆ  \
ಆ ಆ ಊ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಅ ಐ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಎ ಐ  ಏ ಈ  ಈ ಇ  ಎ ಈ  ಆ \
ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಆ ಋ  ಈ \
ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಎ ಈ  ಆ ಆ ಅ  \
ಆ ಆ ಋ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಋ ಊ  ಆ ಆ ಎ  ಆ ಅ ಅ  ಆ ಅ \
ಊ  ಆ ಅ ಆ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಅ ಆ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಋ ಏ  ಆ ಅ ಆ  ಆ ಆ ಏ  ಆ \
ಅ ಆ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಆ ಆ ಊ  ಈ ಐ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ\
  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಐ  ಏ ಉ  ಆ ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಊ  ಐ ಐ  ಈ \
ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಈ  ಆ ಆ ಆ  ಆ ಅ ಇ  ಆ ಆ ಋ  ಆ ಆ ಐ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ ಆ  \
ಈ ಇ  ಋ ಏ  ಆ ಅ ಆ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ ಆ ಆ  ಆ ಆ ಇ  ಆ ಅ ಐ  ಆ ಅ ಆ  ಆ ಆ \
ಅ  ಆ ಆ ಋ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಎ ಋ  ಆ ಅ ಊ  ಐ ಏ  ಆ ಆ ಉ  ಐ ಎ  ಆ ಆ ಉ  ಆ ಅ \
ಊ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಈ ಇ  ಊ ಏ  ಊ ಏ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  \
ಆ ಆ ಅ  ಈ ಇ  ಎ ಎ  ಆ ಆ ಆ  ಆ ಅ ಅ  ಆ ಆ ಎ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಆ ಊ  ಈ ಐ  ಉ ಉ  ಆ\
 ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಐ ಈ  ಉ ಉ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಎ  ಆ ಅ \
ಆ  ಆ ಇ ಆ  ಆ ಆ ಐ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಅ  ಆ ಆ ಊ  ಋ ಆ  ಈ ಐ  ಏ ಉ  ಆ ಅ ಉ  ಆ ಅ\
 ಊ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಊ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಏ ಅ  ಆ ಇ \
ಆ  ಏ ಅ  ಆ ಅ ಊ  ಈ ಇ  ಎ ಎ  ಆ ಆ ಆ  ಆ ಅ ಅ  ಆ ಆ ಎ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಐ\
  ಆ ಅ ಉ  ಆ ಅ ಊ  ಐ ಐ  ಆ ಅ ಉ  ಈ ಇ  ಆ ಅ ಈ  ಆ ಅ ಊ  ಆ ಆ ಏ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ \
ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ ಆ  ಈ\
 ಇ  ಎ ಐ  ಐ ಏ  ಆ ಅ ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಋ  ಆ ಅ ಆ  ಈ ಇ  ಏ ಉ  ಆ\
 ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಏ ಅ  ಆ ಇ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಆ ಆ  ಆ ಆ ಅ  ಈ ಇ  ಆ ಅ ಊ  \
ಆ ಆ ಅ  ಈ ಇ  ಎ ಊ  ಐ ಎ  ಆ ಆ ಅ  ಆ ಆ ಅ  ಐ ಎ  ಆ ಅ ಅ  ಐ ಎ  ಈ ಐ  ಉ ಉ  ಈ ಇ  ಈ \
ಇ  ಈ ಊ  ಈ ಇ  ಎ ಊ  ಆ ಅ ಆ  ಆ ಇ ಆ  ಆ ಆ ಐ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಆ ಅ ಅ  ಆ ಆ ಊ  ಈ ಇ\
  ಆ ಅ ಇ  ಆ ಆ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ \
 ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಐ ಐ \
 ಆ ಅ ಏ  ಆ ಆ ಎ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಐ ಊ  ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  \
ಆ ಅ ಆ  ಐ ಊ  ಆ ಅ ಅ  ಐ ಎ  ಆ ಆ ಋ  ಐ ಎ  ಋ ಆ  ಏ ಉ  ಆ ಆ ಉ  ಆ ಆ ಎ  ಆ ಅ ಆ  ಉ ಉ\
  ಈ ಇ  ಈ ಇ  ಈ ಊ  ಈ ಇ  ಎ ಈ  ಆ ಆ ಅ  ಐ ಐ  ಆ ಅ ಏ  ಆ ಆ ಎ  ಆ ಅ ಅ  ಆ ಅ ಆ  ಈ ಇ\
  ಆ ಆ ಆ  ಆ ಆ ಋ  ಆ ಅ ಉ  ಆ ಅ ಆ  ಆ ಆ ಉ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  \
ಆ ಆ ಊ  ಈ ಇ  ಆ ಆ ಊ  ಆ ಆ ಇ  ಆ ಅ ಆ  ಐ ಐ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಆ  ಆ ಅ \
ಅ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  ಈ ಇ  ಎ ಎ  ಋ ಊ  ಎ ಏ  ಎ ಈ  ಎ ಅ  ಋ ಐ  ಏ ಈ  ಏ ಉ  ಉ ಋ\
  ಆ ಅ ಊ  ಆ ಆ ಅ  ಆ ಅ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಈ ಇ  ಆ ಇ ಇ  ಆ ಅ ಊ  ಆ ಆ ಇ  ಐ ಊ  ಆ ಆ\
 ಊ  ಐ ಎ  ಆ ಅ ಇ  ಆ ಅ ಆ  ಋ ಆ  ಎ ಅ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಉ ಉ  ಈ ಇ  ಈ\
 ಇ  ಈ ಊ  ಈ ಇ  ಏ ಈ  ಆ ಅ ಆ  ಆ ಆ ಋ  ಈ ಇ  ಆ ಆ ಋ  ಆ ಆ ಆ  ಈ ಇ  ಏ ಉ  ಆ ಆ ಉ  ಆ\
 ಆ ಎ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಇ ಆ  ಆ ಆ ಆ  ಆ ಆ ಎ  ಆ ಆ ಉ  ಈ ಇ  \
ಆ ಆ ಇ  ಐ ಎ  ಐ ಐ  ಆ ಅ ಎ  ಐ ಎ  ಆ ಅ ಈ  ಆ ಅ ಆ  ಈ ಇ  ಐ ಐ  ಐ ಎ  ಆ ಆ ಅ  ಈ ಇ  \
ಐ ಏ  ಆ ಅ ಆ  ಈ ಇ  ಆ ಆ ಉ  ಆ ಅ ಆ  ಆ ಅ ಏ  ಆ ಅ ಊ  ಐ ಎ  ಐ ಏ  ಆ ಅ ಏ  ಆ ಇ ಆ  ಈ\
 ಇ  ಆ ಆ ಎ  ಆ ಆ ಊ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಅ ಇ  ಈ ಇ  ಆ ಅ ಊ  ಆ ಆ ಅ  \
ಆ ಆ ಊ  ಆ ಆ ಋ  ಐ ಎ  ಆ ಅ ಏ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ ಅ ಅ  ಈ ಇ  ಐ ಎ  ಆ ಆ ಊ  ಈ ಇ  ಐ\
 ಎ  ಈ ಇ  ಉ ಋ  ಆ ಅ ಆ  ಆ ಅ ಈ  ಆ ಅ ಈ  ಈ ಇ  ಆ ಅ ಇ  ಆ ಅ ಊ  ಆ ಅ ಏ  ಆ ಅ ಆ  ಆ \
ಅ  ಉ ಆ  ಆ ಅ"
.split("  ")])))
